leaftools.get_composite_offset_series_from_leaves_in_expr
=========================================================

.. autofunction:: abjad.tools.leaftools.get_composite_offset_series_from_leaves_in_expr.get_composite_offset_series_from_leaves_in_expr
